<?php
/*
Plugin Name: DZone Widget
Plugin URI: http://www.rockstarapps.com/pmwiki/pmwiki.php?n=Wordpress.Dzone
Description: This plugin allows you to add the dzone widget to wordpress posts.
Version: 2.0
Author: Rockstarapps
Author URI: http://www.rockstarapps.com
Licence: This WordPress plugin is licenced under the GNU General Public Licence. 
For more information see: http://www.gnu.org/copyleft/gpl.html

For documentation, please visit http://www.rockstarapps.com/pmwiki/pmwiki.php?n=Wordpress.Dzone
*/

define('DZONE_VERSION', '2.0.0');

class DZone{

	var $settings = array(
			// Whether to allow overrides
			'AllowOverride' => true
		);

	/* ====== Constructor ====== */

	/**
	 * Initialises the plugin, setting up the actions and filters.
	 */

	function DZone(){
		add_filter('the_posts', array(&$this, 'process_posts'));
		add_filter('the_content', array(&$this, 'the_content'));
		add_action('admin_menu', array(&$this, 'add_config_page'));
		add_action('dbx_post_advanced', array(&$this, 'post_sidebar'));

		// Needs to be called before Akismet
		add_action('save_post', array(&$this, 'save_post'));
		
		$this->loadSettings();
	}
	
	function loadSettings(){
		$this->WhenToDisplay = get_option('dzone_when_to_display');
		if (FALSE === $this->DisplayAsTitle) {
			$this->WhenToDisplay = "0";
			add_option('dzone_when_to_display', "0");
		}			
		$this->HowToDisplay = get_option('dzone_how_to_display');
		if (FALSE === $this->HowToDisplay) {
			$this->HowToDisplay = "0";
			add_option('dzone_how_to_display', "0");
		}
		$this->WhereToDisplay = get_option('dzone_where_to_display');
		if (FALSE === $this->WhereToDisplay) {
			$this->WhereToDisplay = "1";
			add_option('dzone_where_to_display', "1");
		}			
	}

	/* ====== add_config_page ====== */

	/**
	 * Adds the configuration page to the submenu
	 */
	function add_config_page(){
		add_submenu_page('options-general.php', __('DZone'), __('DZone'), 'manage_options', 'dzone', array(&$this, 'config_page'));
	}

	function config_page() {
		if ('POST' == $_SERVER['REQUEST_METHOD']) {
			$this->WhenToDisplay = $_POST['WhenToDisplay'];
			update_option('dzone_when_to_display', $this->WhenToDisplay);
			
			$this->HowToDisplay = $_POST['HowToDisplay'];
			update_option('dzone_how_to_display', $this->HowToDisplay);
						
			$this->WhereToDisplay = $_POST['WhereToDisplay'];
			update_option('dzone_where_to_display', $this->WhereToDisplay);
			
			echo '<div id="comment-locking-saved" class="updated fade-ffff00"">';
			echo '<p><strong>';
			_e('Options saved.');
			echo '</strong></p></div>';
		}
		else {
			$this->loadSettings();
		}
		require_once(dirname(__FILE__) . '/dzone.config.php');
	}

	/**
	 * Adds an entry to the post's sidebar to allow us to set simple comment
	 * settings on a post-by-post basis.
	 */
	function post_sidebar(){
		if ($this->settings['AllowOverride']) {
			require_once(dirname(__FILE__) . '/dzone.post.php');
		}
	}	
	
	/* ====== save_post ====== */

	/**
	 * Called when a post or page is saved. Updates DZone per-post settings
	 * from the bit in the sidebar.
	 */
	function save_post($postID){
		if ($this->settings['AllowOverride']) {
			$dzDisplay = $_POST['dzDisplay'];
			$dzUrl = $_POST['dzUrl'];
			if ($dzDisplay == "on"){
				$dzDisplay = 'true';
			}else{
				$dzDisplay = 'false';
			}
			
			if ($display !== false) {
				if (!update_post_meta($postID, '_dzone', $dzDisplay."<-->".$dzUrl)) {
					add_post_meta($postID, '_dzone', $dzDisplay."<-->".$dzUrl);
				}
			}else {
				delete_post_meta($postID, '_dzone');
			}
		}
	}

	/* ====== process_posts ====== */

	/**
	 * Goes through the list of posts, checking each one to see if it should
	 * have comments closed.
	 */

	/* ====== process_posts ====== */

	/**
	 * Goes through the list of posts, checking each one to see if it should
	 * have comments closed.
	 */

	function process_posts($posts){
		// Check that we have an array of posts
		$this->loadSettings();

		if (!is_array($posts)) {
			// Is it a single post? If so, process it as an array of posts
			if (is_object($posts) && isset($posts->dzDisplay)) {
				$p = $this->process_posts(array($posts));
				return $p[0];
			}
			else {
				// Otherwise don't do anything
				return $posts;
			}
		}
		// NB need to get the keys and values this way because PHP 4 gets funny
		// about references if you do foreach ($posts as $k => $p)
		foreach (array_keys($posts) as $k) {
			$p =& $posts[$k];
			$setting = get_post_meta($p->ID, '_dzone', true);
			
			$setting = split("<-->", $setting);

			//Post display setting
			$p->dzDisplay = $setting[0];

			//keep the override URL around to display it later
			$p->dzUrl = $setting[1];
		}

		return $posts;
	}
	
	function the_content($content){	
		global $post;
		if (display_dzone_widget($post) == true){
			if ($post->dzUrl != ''){
				echo '<script type="text/javascript">dzone_url = "'.$post->dzUrl.'/?p='.$post->ID.'";</script>';				
			}else{
				$dzUrl = get_permalink($post->ID);
				echo '<script type="text/javascript">dzone_url = "'.$dzUrl.'";</script>';				
			}
			if ($this->HowToDisplay == "0"){
				if ($this->WhereToDisplay == "1"){
					return '<script language="javascript" src="http://widgets.dzone.com/widgets/zoneit.js"></script>'.$content;
				}else if ($this->WhereToDisplay == "2"){
					return $content.'<script language="javascript" src="http://widgets.dzone.com/widgets/zoneit.js"></script>';
				}
			}else{
				if ($this->WhereToDisplay == "1"){
					return '<script>var dzone_style="2";</script><script language="javascript" src="http://widgets.dzone.com/widgets/zoneit.js"></script>'.$content;
				}else if ($this->WhereToDisplay == "2"){
					return $content.'<script>var dzone_style="2";</script><script language="javascript" src="http://widgets.dzone.com/widgets/zoneit.js"></script>';
				}
			}	
		}
		return $content;
	}
	
}

$myDzone = new DZone();

/**
 *  Function writes in the dzone widget
 */
function echo_dzone_widget($post, $type){
	if ($post->dzUrl != ''){
		//This is a hack so I don't need to change all my post settings again
		echo '<script type="text/javascript">dzone_url = "'.$post->dzUrl.'/?p='.$post->ID.'";</script>';				
	}else{
		$dzUrl = get_permalink($post->ID);
		echo '<script type="text/javascript">dzone_url = "'.$dzUrl.'";</script>';				
	}
	echo '<script type="text/javascript">var dzone_style = "'.$type.'";</script>';
	echo '<script language="javascript" src="http://widgets.dzone.com/widgets/zoneit.js"></script>';	
}

/**
 *  Function writes in the dzone widget
 */
function display_dzone_widget($post){
	global $myDzone;
	//all posts
	if ($myDzone->WhenToDisplay == "0"){
		return true;	
	//manual override
	}else if ($myDzone->WhenToDisplay == "1"){
		return $post->dzDisplay == "true";	
	//no posts
	}else{
		return false;	
	}
}

?>